Supporting the project
======================


`PyFunceble`_, `Dead-Hosts`_, and all other analogue projects are powered by my 
free time and a lot of coffee!

If you like this project and/or it have helped you. Please consider buying me 
more coffee.

GitHub Sponsor
--------------

`@funilrys`_ is part of the GitHub Sponsor program!

*GitHub will match all donation for the coming months!*

.. image:: https://github.com/PyFunceble/logo/raw/master/pyfunceble_github.png
    :target: https://github.com/sponsors/funilrys
    :height: 70px

`Sponsor me`_!

Ko-Fi
-----

Don't want to use the GitHub Sponsor program ?
Single donation are welcome too!

.. image:: https://az743702.vo.msecnd.net/cdn/kofi3.png
    :target: https://ko-fi.com/V7V3EH2Y
    :height: 70px

`Buy me a coffee`_!


.. _@funilrys: https://github.com/funilrys
.. _PyFunceble: https://github.com/funilrys/PyFunceble
.. _Dead-Hosts: https://github.com/dead-hosts
.. _Sponsor me: https://github.com/sponsors/funilrys
.. _Buy me a coffee: https://ko-fi.com/V7V3EH2Y
